# picteus-ws-client
The Picteus API

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.12.0
- Package version: 0.12.0
- Generator version: 7.17.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://www.linkedin.com/in/edouardmercier](https://www.linkedin.com/in/edouardmercier)

## Requirements.

Python 3.9+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/picteus/picteus.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/picteus/picteus.git`)

Then import the package:
```python
import picteus_ws_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import picteus_ws_client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import picteus_ws_client
from picteus_ws_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://localhost:3001
# See configuration.py for a list of all supported configuration parameters.
configuration = picteus_ws_client.Configuration(
    host = "https://localhost:3001"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: api-key
configuration.api_key['api-key'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['api-key'] = 'Bearer'


# Enter a context with an instance of the API client
with picteus_ws_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = picteus_ws_client.AdministrationApi(api_client)

    try:
        # Migrates the database
        api_instance.administration_migrate_database()
    except ApiException as e:
        print("Exception when calling AdministrationApi->administration_migrate_database: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://localhost:3001*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AdministrationApi* | [**administration_migrate_database**](docs/AdministrationApi.md#administration_migrate_database) | **PUT** /administration/migrateDatabase | Migrates the database
*ApiSecretApi* | [**apisecret_create**](docs/ApiSecretApi.md#apisecret_create) | **POST** /apiSecret/create | Creates an API secret
*ApiSecretApi* | [**apisecret_delete**](docs/ApiSecretApi.md#apisecret_delete) | **DELETE** /apiSecret/{id}/delete | Deletes an API secret
*ApiSecretApi* | [**apisecret_get**](docs/ApiSecretApi.md#apisecret_get) | **GET** /apiSecret/{id}/get | Gets an API secret
*ApiSecretApi* | [**apisecret_list**](docs/ApiSecretApi.md#apisecret_list) | **GET** /apiSecret/list | Lists all API secrets
*CollectionApi* | [**collection_create**](docs/CollectionApi.md#collection_create) | **POST** /collection/create | Creates a collection
*CollectionApi* | [**collection_delete**](docs/CollectionApi.md#collection_delete) | **DELETE** /collection/{id}/delete | Deletes collection
*CollectionApi* | [**collection_get**](docs/CollectionApi.md#collection_get) | **GET** /collection/{id}/get | Gets a collection
*CollectionApi* | [**collection_list**](docs/CollectionApi.md#collection_list) | **GET** /collection/list | Lists all collections
*CollectionApi* | [**collection_update**](docs/CollectionApi.md#collection_update) | **PUT** /collection/{id}/update | Updates a collection
*ExtensionApi* | [**extension_activities**](docs/ExtensionApi.md#extension_activities) | **GET** /extension/activities | Indicates the extension activities
*ExtensionApi* | [**extension_build**](docs/ExtensionApi.md#extension_build) | **PUT** /extension/build | Builds an extension
*ExtensionApi* | [**extension_generate**](docs/ExtensionApi.md#extension_generate) | **PUT** /extension/generate | Generates an extension
*ExtensionApi* | [**extension_get**](docs/ExtensionApi.md#extension_get) | **GET** /extension/{id}/get | Gets an extension
*ExtensionApi* | [**extension_get_configuration**](docs/ExtensionApi.md#extension_get_configuration) | **GET** /extension/getConfiguration | Provides the extensions configuration
*ExtensionApi* | [**extension_get_settings**](docs/ExtensionApi.md#extension_get_settings) | **GET** /extension/{id}/getSettings | Gets an extension settings
*ExtensionApi* | [**extension_install**](docs/ExtensionApi.md#extension_install) | **POST** /extension/install | Installs an extension
*ExtensionApi* | [**extension_install_chrome_extension**](docs/ExtensionApi.md#extension_install_chrome_extension) | **PUT** /extension/{id}/installChromeExtension | Installs a Chrome extension
*ExtensionApi* | [**extension_list**](docs/ExtensionApi.md#extension_list) | **GET** /extension/list | Lists all extensions
*ExtensionApi* | [**extension_pause_or_resume**](docs/ExtensionApi.md#extension_pause_or_resume) | **PUT** /extension/{id}/pauseOrResume | Pauses or resumes an extension
*ExtensionApi* | [**extension_run_image_command**](docs/ExtensionApi.md#extension_run_image_command) | **PUT** /extension/{id}/runImageCommand | Runs a command exposed by an extension, on images
*ExtensionApi* | [**extension_run_process_command**](docs/ExtensionApi.md#extension_run_process_command) | **PUT** /extension/{id}/runProcessCommand | Runs a command exposed by an extension, on the process
*ExtensionApi* | [**extension_set_settings**](docs/ExtensionApi.md#extension_set_settings) | **PUT** /extension/{id}/setSettings | Sets an extension settings
*ExtensionApi* | [**extension_synchronize**](docs/ExtensionApi.md#extension_synchronize) | **PUT** /extension/{id}/synchronize | Synchronizes the images via an extension
*ExtensionApi* | [**extension_uninstall**](docs/ExtensionApi.md#extension_uninstall) | **DELETE** /extension/{id}/uninstall | Uninstalls an extension
*ExtensionApi* | [**extension_update**](docs/ExtensionApi.md#extension_update) | **PUT** /extension/{id}/update | Updates an extension
*ImageApi* | [**image_closest_embeddings_images**](docs/ImageApi.md#image_closest_embeddings_images) | **PUT** /image/closestEmbeddingsImages | Gets the closest images to some embeddings attached to an extension
*ImageApi* | [**image_closest_images**](docs/ImageApi.md#image_closest_images) | **GET** /image/{id}/closestImages | Gets the closest images to the image following the embeddings of an extension
*ImageApi* | [**image_compute_format**](docs/ImageApi.md#image_compute_format) | **PUT** /image/format | Computes the format of an image
*ImageApi* | [**image_convert**](docs/ImageApi.md#image_convert) | **PUT** /image/convert | Converts an image into a format
*ImageApi* | [**image_delete**](docs/ImageApi.md#image_delete) | **DELETE** /image/{id}/delete | Deletes an image
*ImageApi* | [**image_download**](docs/ImageApi.md#image_download) | **GET** /image/{id}/download | Downloads an image
*ImageApi* | [**image_ensure_tags**](docs/ImageApi.md#image_ensure_tags) | **PUT** /image/{id}/ensureTags | Ensures that the tags are set on an image
*ImageApi* | [**image_get**](docs/ImageApi.md#image_get) | **GET** /image/{id}/get | Gets an image
*ImageApi* | [**image_get_all_embeddings**](docs/ImageApi.md#image_get_all_embeddings) | **GET** /image/{id}/getAllEmbeddings | Gets all the embeddings of an image
*ImageApi* | [**image_get_all_features**](docs/ImageApi.md#image_get_all_features) | **GET** /image/{id}/getAllFeatures | Gets all the features of an image
*ImageApi* | [**image_get_all_recipes**](docs/ImageApi.md#image_get_all_recipes) | **GET** /image/{id}/getAllRecipes | Gets all the recipes of an image
*ImageApi* | [**image_get_all_tags**](docs/ImageApi.md#image_get_all_tags) | **GET** /image/{id}/getAllTags | Gets all the tags of an image
*ImageApi* | [**image_get_embeddings**](docs/ImageApi.md#image_get_embeddings) | **GET** /image/{id}/getEmbeddings | Gets the embeddings of an image
*ImageApi* | [**image_get_features**](docs/ImageApi.md#image_get_features) | **GET** /image/{id}/getFeatures | Gets all the features of an image for an extension
*ImageApi* | [**image_get_metadata**](docs/ImageApi.md#image_get_metadata) | **GET** /image/{id}/metadata | Gets the metadata of an image
*ImageApi* | [**image_get_tags**](docs/ImageApi.md#image_get_tags) | **GET** /image/{id}/getTags | Gets the tags of an image for an extension
*ImageApi* | [**image_media_url**](docs/ImageApi.md#image_media_url) | **GET** /image/{id}/mediaUrl | Gets an URL of the image
*ImageApi* | [**image_modify**](docs/ImageApi.md#image_modify) | **PUT** /image/{id}/modify | Modifies an image
*ImageApi* | [**image_search_features**](docs/ImageApi.md#image_search_features) | **POST** /image/search/features | Retrieves image features
*ImageApi* | [**image_search_images**](docs/ImageApi.md#image_search_images) | **POST** /image/search/images | Retrieves image details
*ImageApi* | [**image_search_media_url**](docs/ImageApi.md#image_search_media_url) | **POST** /image/search/mediaUrls | Retrieves image media URLs
*ImageApi* | [**image_search_summaries**](docs/ImageApi.md#image_search_summaries) | **POST** /image/search/summaries | Retrieves image summaries
*ImageApi* | [**image_search_tags**](docs/ImageApi.md#image_search_tags) | **POST** /image/search/tags | Retrieves image tags
*ImageApi* | [**image_set_embeddings**](docs/ImageApi.md#image_set_embeddings) | **PUT** /image/{id}/setEmbeddings | Sets the embeddings of an image
*ImageApi* | [**image_set_features**](docs/ImageApi.md#image_set_features) | **PUT** /image/{id}/setFeatures | Sets the features of an image
*ImageApi* | [**image_set_tags**](docs/ImageApi.md#image_set_tags) | **PUT** /image/{id}/setTags | Sets the tags of an image
*ImageApi* | [**image_synchronize**](docs/ImageApi.md#image_synchronize) | **PUT** /image/{id}/synchronize | Synchronizes an image
*ImageApi* | [**image_text_to_images**](docs/ImageApi.md#image_text_to_images) | **GET** /image/textToImages | Gets the closest images to a text following the embeddings of an extension
*ImageAttachmentApi* | [**imageattachment_create**](docs/ImageAttachmentApi.md#imageattachment_create) | **POST** /imageAttachment/create | Declares an image binary attachment
*ImageAttachmentApi* | [**imageattachment_download**](docs/ImageAttachmentApi.md#imageattachment_download) | **GET** /imageAttachment/{uri}/download | Downloads an image binary attachment
*MiscellaneousApi* | [**miscellaneous_ping**](docs/MiscellaneousApi.md#miscellaneous_ping) | **GET** /miscellaneous/ping | Pings the service
*MiscellaneousApi* | [**miscellaneous_test**](docs/MiscellaneousApi.md#miscellaneous_test) | **GET** /miscellaneous/test | Runs a test
*RepositoryApi* | [**repository_activities**](docs/RepositoryApi.md#repository_activities) | **GET** /repository/activities | Indicates the repositories activities
*RepositoryApi* | [**repository_create**](docs/RepositoryApi.md#repository_create) | **POST** /repository/create | Creates a repository
*RepositoryApi* | [**repository_delete**](docs/RepositoryApi.md#repository_delete) | **DELETE** /repository/{id}/delete | Deletes a repository
*RepositoryApi* | [**repository_ensure**](docs/RepositoryApi.md#repository_ensure) | **PUT** /repository/ensure | Ensures a repository exists
*RepositoryApi* | [**repository_get**](docs/RepositoryApi.md#repository_get) | **GET** /repository/{id}/get | Gets a repository
*RepositoryApi* | [**repository_get_feature_names**](docs/RepositoryApi.md#repository_get_feature_names) | **GET** /repository/featureNames | Gets all the feature names
*RepositoryApi* | [**repository_get_image_by_url**](docs/RepositoryApi.md#repository_get_image_by_url) | **GET** /repository/getImageByUrl | Gets an image from its URL
*RepositoryApi* | [**repository_get_tags**](docs/RepositoryApi.md#repository_get_tags) | **GET** /repository/tags | Gets all the tags
*RepositoryApi* | [**repository_list**](docs/RepositoryApi.md#repository_list) | **GET** /repository/list | Lists repositories
*RepositoryApi* | [**repository_rename_image**](docs/RepositoryApi.md#repository_rename_image) | **PUT** /repository/{id}/renameImage | Renames an image
*RepositoryApi* | [**repository_start_or_stop**](docs/RepositoryApi.md#repository_start_or_stop) | **PUT** /repository/startOrStop | Starts or stop the repositories
*RepositoryApi* | [**repository_store_image**](docs/RepositoryApi.md#repository_store_image) | **POST** /repository/{id}/storeImage | Creates an image in the repository
*RepositoryApi* | [**repository_synchronize**](docs/RepositoryApi.md#repository_synchronize) | **PUT** /repository/{id}/synchronize | Synchronizes a repository
*RepositoryApi* | [**repository_watch**](docs/RepositoryApi.md#repository_watch) | **PUT** /repository/{id}/watch | Starts or stops watching a repository
*SettingsApi* | [**settings_get**](docs/SettingsApi.md#settings_get) | **GET** /settings/get | Gets all the settings
*SettingsApi* | [**settings_set**](docs/SettingsApi.md#settings_set) | **PUT** /settings/set | Sets all the settings


## Documentation For Models

 - [ApiSecret](docs/ApiSecret.md)
 - [ApiSecretSummary](docs/ApiSecretSummary.md)
 - [ApiSecretType](docs/ApiSecretType.md)
 - [ApplicationMetadata](docs/ApplicationMetadata.md)
 - [ApplicationMetadataItem](docs/ApplicationMetadataItem.md)
 - [ApplicationMetadataItemValue](docs/ApplicationMetadataItemValue.md)
 - [Collection](docs/Collection.md)
 - [CommandEntity](docs/CommandEntity.md)
 - [ComputedImageFormat](docs/ComputedImageFormat.md)
 - [ConfigurationCapability](docs/ConfigurationCapability.md)
 - [ConfigurationExtensionCommand](docs/ConfigurationExtensionCommand.md)
 - [ConstantsRegistry](docs/ConstantsRegistry.md)
 - [Dates](docs/Dates.md)
 - [Extension](docs/Extension.md)
 - [ExtensionActivity](docs/ExtensionActivity.md)
 - [ExtensionActivityKind](docs/ExtensionActivityKind.md)
 - [ExtensionAndManual](docs/ExtensionAndManual.md)
 - [ExtensionGenerationOptions](docs/ExtensionGenerationOptions.md)
 - [ExtensionImageEmbeddings](docs/ExtensionImageEmbeddings.md)
 - [ExtensionImageFeature](docs/ExtensionImageFeature.md)
 - [ExtensionImageFeatureName](docs/ExtensionImageFeatureName.md)
 - [ExtensionImageFeaturesAttribute](docs/ExtensionImageFeaturesAttribute.md)
 - [ExtensionImageTag](docs/ExtensionImageTag.md)
 - [ExtensionImageTagsAttribute](docs/ExtensionImageTagsAttribute.md)
 - [ExtensionManual](docs/ExtensionManual.md)
 - [ExtensionSettings](docs/ExtensionSettings.md)
 - [ExtensionStatus](docs/ExtensionStatus.md)
 - [ExtensionsConfiguration](docs/ExtensionsConfiguration.md)
 - [GenerationRecipe](docs/GenerationRecipe.md)
 - [GenerationRecipePrompt](docs/GenerationRecipePrompt.md)
 - [Image](docs/Image.md)
 - [ImageDimensions](docs/ImageDimensions.md)
 - [ImageDistance](docs/ImageDistance.md)
 - [ImageEmbeddings](docs/ImageEmbeddings.md)
 - [ImageFeature](docs/ImageFeature.md)
 - [ImageFeatureFormat](docs/ImageFeatureFormat.md)
 - [ImageFeatureNullValue](docs/ImageFeatureNullValue.md)
 - [ImageFeatureType](docs/ImageFeatureType.md)
 - [ImageFeatureValue](docs/ImageFeatureValue.md)
 - [ImageFormat](docs/ImageFormat.md)
 - [ImageMediaUrl](docs/ImageMediaUrl.md)
 - [ImageMetadata](docs/ImageMetadata.md)
 - [ImageResizeRender](docs/ImageResizeRender.md)
 - [ImageSummary](docs/ImageSummary.md)
 - [InstructionsPrompt](docs/InstructionsPrompt.md)
 - [Manifest](docs/Manifest.md)
 - [ManifestCapability](docs/ManifestCapability.md)
 - [ManifestCapabilityId](docs/ManifestCapabilityId.md)
 - [ManifestEvent](docs/ManifestEvent.md)
 - [ManifestExecution](docs/ManifestExecution.md)
 - [ManifestExtensionCommand](docs/ManifestExtensionCommand.md)
 - [ManifestExtensionCommandOn](docs/ManifestExtensionCommandOn.md)
 - [ManifestExtensionCommandSpecification](docs/ManifestExtensionCommandSpecification.md)
 - [ManifestInstructions](docs/ManifestInstructions.md)
 - [ManifestInterfaceElement](docs/ManifestInterfaceElement.md)
 - [ManifestRuntime](docs/ManifestRuntime.md)
 - [ManifestRuntimeEnvironment](docs/ManifestRuntimeEnvironment.md)
 - [ManifestThrottlingPolicy](docs/ManifestThrottlingPolicy.md)
 - [ManifestUserInterface](docs/ManifestUserInterface.md)
 - [PromptKind](docs/PromptKind.md)
 - [Repository](docs/Repository.md)
 - [RepositoryActivity](docs/RepositoryActivity.md)
 - [RepositoryActivityKind](docs/RepositoryActivityKind.md)
 - [RepositoryLocationType](docs/RepositoryLocationType.md)
 - [RepositoryStatus](docs/RepositoryStatus.md)
 - [SearchCriteria](docs/SearchCriteria.md)
 - [SearchFeatureComparisonOperator](docs/SearchFeatureComparisonOperator.md)
 - [SearchFeatureCondition](docs/SearchFeatureCondition.md)
 - [SearchFeatureConditionValue](docs/SearchFeatureConditionValue.md)
 - [SearchFeatureLogicalOperator](docs/SearchFeatureLogicalOperator.md)
 - [SearchFeatures](docs/SearchFeatures.md)
 - [SearchFeaturesResult](docs/SearchFeaturesResult.md)
 - [SearchFilter](docs/SearchFilter.md)
 - [SearchFilterOrigin](docs/SearchFilterOrigin.md)
 - [SearchImageResult](docs/SearchImageResult.md)
 - [SearchImageSummaryResult](docs/SearchImageSummaryResult.md)
 - [SearchImagesOrigin](docs/SearchImagesOrigin.md)
 - [SearchKeyword](docs/SearchKeyword.md)
 - [SearchMediaUrlResult](docs/SearchMediaUrlResult.md)
 - [SearchOriginNature](docs/SearchOriginNature.md)
 - [SearchParameters](docs/SearchParameters.md)
 - [SearchProperties](docs/SearchProperties.md)
 - [SearchPropertyRange](docs/SearchPropertyRange.md)
 - [SearchRange](docs/SearchRange.md)
 - [SearchRepositoriesOrigin](docs/SearchRepositoriesOrigin.md)
 - [SearchSorting](docs/SearchSorting.md)
 - [SearchSortingProperty](docs/SearchSortingProperty.md)
 - [SearchTags](docs/SearchTags.md)
 - [SearchTagsResult](docs/SearchTagsResult.md)
 - [Settings](docs/Settings.md)
 - [Software](docs/Software.md)
 - [TextualPrompt](docs/TextualPrompt.md)
 - [UserInterfaceAnchor](docs/UserInterfaceAnchor.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="api-key"></a>
### api-key

- **Type**: API key
- **API key parameter name**: X-API-KEY
- **Location**: HTTP header


## Author

edouard@koppasoft.com


